==> resevol_0.2.0.2.tar.gz: resevol/R/gmatrices.R <==
#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 1)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_n1"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 2)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_n2"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 3)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_n3"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure  of the identity matrix (replicate 4)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_n4"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 5)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_n5"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 1)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_v1"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 2)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_v2"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 3)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_v3"



#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 4)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_v4"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 5)
#'
#' @format A list of 8 elements used in individual-based model initialisation
"mg_v5"

==> resevol_0.3.4.0.tar.gz: resevol/R/gmatrices.R <==
#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 1)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_n1"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 2)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_n2"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 3)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_n3"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure  of the identity matrix (replicate 4)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_n4"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure of the identity matrix (replicate 5)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_n5"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 1)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_v1"

#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 2)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_v2"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 3)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_v3"



#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 4)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_v4"


#' Sample mine_gmatrix outputs
#'
#' Output from mine_gmatrix that maps random normals from 12 loci to four traits
#' with a covariance structure including negative and positive values 
#' (replicate 5)
#'
#' @format A list of 8 elements used in individual-based model initialisation
#' @keywords internal
"mg_v5"
